function result = exploitation(TalphaPlus, TindMPlus, TR, Mlibrary, wavelength, Nbi, Nmc)

%------------------------------------------------------------------
% This function allows to exploit the results provided by
%       the function unmixing
% 
% INPUT
%       TalphaPlus : the MCMC samples alphaPlus
%       TindMPlus  : the MCMC samples for the endmember matrix (indices)
%       Mlibrary   : the library used by the sampler
%       wavelength : spectral bands
%       Nbi        : number of burn-in iterations
%       Nmc        : length of the Markov Chain
%
% OUTPUT
%       result : 1 if the function is correctly used, 0 otherwise
%
%------------------------------------------------------------------

Nr = Nmc - Nbi;
TR = TR(1:Nmc);


% the library
figure
for i=1:6
    subplot(3,2,i)
    plot(wavelength,Mlibrary(:,i))
    ylabel('Reflectance')
    axis([0.3 2.6 0 1.1*max(Mlibrary(:,i))])
    switch i
        case 1
            title('Construction Concrete')
             %axis([0.3 2.6 0 0.6])
        case 2
            title('Green Grass')
           %axis([0.3 2.6 0 0.6])
        case 3
            title('Micaceous Loam')
        case 4
            title('Olive Green Paint')
        case 5
            title('Bare Red Brick')
        case 6
            title('Galvanized Steel Metal')
    end
    xlabel('Wavelength ({\mu}m)')
    ylabel('Reflectance')
end


% posterior distribution of R (number of components)
figure
set(gca,'fontsize',12)
bar(2:5,hist(TR(Nbi:Nmc),2:5)/Nr,'k')
axis([1.5 5.5 0 1])
xlabel('R')
ylabel('f(R|Y)')

M = TindMPlus(:,Nbi+1:Nmc);


% combinations estimated : {1,2,3} or {1,2,5}
ind3 = find(TR(Nbi+1:Nmc) == 3);
compt123 = 0;
compt125 = 0;
ind123 = [];
ind125 = [];

for k=ind3
    if M(4:6,k)== [1 2 3]'
        compt123 = compt123 + 1;
        ind123 = [ind123 k];
    else
        if M(4:6,k) == [1 2 5]'
            compt125 = compt125 + 1;
            ind125 = [ind125 k];
        end
    end       
end

figure
set(gca,'fontsize',12)
bar([1 2],[length(ind123) length(ind125)]/length(ind3),'k')
axis([0.5 2.5 0 1])
set(gca,'xticklabel',{'{1,2,3}' '{1,2,5}'})


% posterior distribution of \alpha conditioned to the combination {1,2,3}
TalphaPlus123 = TalphaPlus(1:3,ind123+Nbi);
R = 3;
pas = 0.005;

figure
for i=1:R
    subplot(1,R,i)
    set(gca,'fontsize',12)
    h = hist(TalphaPlus123(i,:),0:pas:1);
    plot(0:pas:1,h,'k')
    set(gca,'ytick',[]);
    switch i
        case 1
            axis([0.1 0.5 0 max(h)*1.1]);
            ylabel('f(\alpha_1|M^+=[S_1 S_2 S_3],Y)');
        case 2
            axis([0.5 0.7 0 max(h)*1.1]);
            ylabel('f(\alpha_2|M^+=[S_1 S_2 S_3],Y)');
        case 3
            ylabel('f(\alpha_3|M^+=[S_1 S_2 S_3],Y)');
            axis([0 0.2 0 max(h)*1.1]);
    end
end


result = 1;
